package uicc.contactmanager;


/**
 * <p>
 *   The <code>ContactManager</code> class gives access to the contact manager information base.
 * </p>
 * <p>
 *   A contact manager is composed of:
 *   <ul>
 *     <li>A unique field descriptors list, that contains all
 *         field descriptors currently defined for the contact manager.</li>
 *     <li>A unique contacts list, that contains all contacts
 *         stored in the contact manager.</li>
 *     <li>A unique groups list, that contains all contact groups 
 *         defined from contacts in the contacts list.</li>
 *   </ul>
 * </p>
 * <p>
 *   An application needs to first get a reference to the <code>ContactManager</code> instance 
 *   using the <code>getContactManager()</code> method.
 *   <br>
 *   Then it can use the methods provided by this instance to create
 *   <code>FieldDescriptorsListView</code>, <code>ContactsListView</code> and <code>GroupsListView</code> instances 
 *   that will allow it to access these collections.
 * </p>
 * <p>
 *   The ContactManager instance is a Permanent JCRE EntryPoint object.
 * </p>
 */
public class ContactManager {
    
    /**
     * Returns the ContactManager singleton.<br>
     * <br>
     * This instance is a JCRE Permanent Entry Point Object.<br>
     * This method should be called during application installation, and the
     * reference stored for use during the application's lifetime.
     * 
     * @return the ContactManager instance.
     */
    public static ContactManager getContactManager() {
        return null;
    }
    
    /**
     * <p>
     *   Factory method that returns a <code>ContactsListView</code> instance that 
     *   represents the contact manager's contacts list.
     * </p>
     * <p>
     *   The instance returned is owned by the calling application.
     * </p>
     * <p>
     *   Successive calls to this method will return distinct instances.
     *   Although they may represent the same contacts list, each of them has its 
     *   own state.
     *   <br>
     *   This particularly applies to the current enumeration progress, which is specific to
     *   each instance.
     * </p>
     * 
     * @return the new <code>ContactsListView</code> instance
     */
    public ContactsListView createContactsListViewInstance() {
        return null;
    }
    
    /**
     * <p>
     *   Factory method that returns a <code>FieldDescriptorsListView</code> instance that 
     *   represents the contact manager's field descriptors list.
     * </p>
     * <p>
     *   The instance returned is owned by the calling application.
     * </p>
     * <p>
     *   Successive calls to this method will return distinct instances.
     *   Although they may represent the same field descriptors list, each of them has its 
     *   own state.
     *   <br>
     *   This particularly applies to the current enumeration progress, which is specific to
     *   each instance.
     * </p>
     * 
     * @return the new FieldsDescriptorsList instance
     */
    public FieldDescriptorsListView createFieldDescriptorsListViewInstance() {
        return null;
    }

    /**
     * <p>
     *   Factory method that returns a <code>GroupsListView</code> instance that 
     *   represents the contact manager's groups list.
     * </p>
     * <p>
     *   The instance returned is owned by the calling application.
     * </p>
     * <p>
     *   Successive calls to this method will return distinct instances.
     *   Although they may represent the same groups list, each of them has its 
     *   own state.
     *   <br>
     *   This particularly applies to the current enumeration progress, which is specific to
     *   each instance.
     * </p>
     * 
     * @return the new GroupsListView instance
     */
    public GroupsListView createGroupsListViewInstance() {
        return null;
    }

    /**
     * <p>
     *   Registers a ContactEventListener to the ContactManager.
     * </p>
     * <p>
     *   Caution: The implementation of this method must avoid any action 
     *   that would cause a recursive invocation.
     * </p>
     *  
     * @param contactEventListener the event listener to register 
     */
    public void registerContactEventListener(ContactEventListener contactEventListener) {
    }

    /**
     * <p>
     *   Deregisters a ContactEventListener from the ContactManager.
     * </p> 
     *  
     * @param contactEventListener the event listener to deregister
     */
    public void deregisterContactEventListner(ContactEventListener contactEventListener) {
    }
}
