package uicc.contactmanager;
import javacard.framework.CardRuntimeException;

/**
 * <p>
 *   <code>ContactManager</code> classes may throw <code>ContactManagerException</code> exceptions.
 * </p>
 * The associated reason code indicates the condition that led to the
 * exception.
 */
public class ContactManagerException extends CardRuntimeException {
    protected static ContactManagerException theException = null;
    
    public ContactManagerException(short reason) {
        super(reason);
    }
    
    /**
     * This exception code indicates that an instance of ContactManager is used without initialization.
     */
    public static final short OBJECT_NOT_INITIALIZED = 0x0001;

    /**
     * This exception code indicates that the identifier is wrong.
     */	
    public static final short WRONG_IDENTIFIER = 0x0002;

    /**
     * This exception code indicates that an operation failed because the object was
     * in an inappropriate state.
     */
    public static final short WRONG_STATE = 0x0003;
    
    /**
     * This exception code indicates that the operation can't be done because an enumeration
     * is currently in progress. 
     */
    public static final short ENUMERATION_IN_PROGRESS = 0x0004;
    
    /**
     * This exception code indicates that an improper field index has been provided. 
     */
    public static final short WRONG_KEY = 0x0005;

    /**
     * This exception code indicates that an operation fails because an update is in progress for 
     * the same item.
     */
    public static final short UPDATE_IN_PROGRESS = 0x0006;
    
    /**
     * This exception code indicates that an operation failed because the concerned item
     * is currently selected by a view.
     */
    public static final short ITEM_SELECTED = 0x0007;
    
    /**
     * This exception code indicates that an operation to a field failed because the concerned item
     * is has a type incompatible with the operation.
     */
    public static final short WRONG_FIELD_TYPE = 0x0008;
    
    /**
     * Throw an instance of the exception.<br>
     * This method allows implementing this exception as a Singleton to avoid run-time
     * allocation of the exception instance.
     * 
     * @param reason The reason that justifies the occurrence of the exception.
     */
    public static void throwIt(short reason) 
    {
        if (theException == null) {
            theException = new ContactManagerException(reason);
        } else {
            theException.setReason(reason);
        }
        throw theException;
    }
}
